<?php
/*
Copyright (©) 2003-2013 Teus Benschop.

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3 of the License, or
(at your option) any later version.
  
This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
  
You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/


require_once ("bootstrap/bootstrap.php");


class SendReceive_Logic
{


  static public function start ()
  {
    $timer_logger = new Timer_Logger ();
    $timer_logger->startProcess (dirname (__FILE__), "php", "sendreceive.php", NULL, "sendreceive");
  }


  static public function isRunning ()
  {
    $database_logger = Database_Logger::getInstance ();
    $count = $database_logger->count ("sendreceive");
    return ($count > 0);
  }


}


?>
